@@ -36,15 +36,6 @@ my $Max_Path_Length = ( $^O eq 'MSWin32' ? 254 : 1023 );
 my $Fetch_Flags     = O_RDONLY | O_BINARY;
 my $Store_Flags     = O_WRONLY | O_CREAT | O_BINARY;
 
-sub BUILD {
-    my ( $self, $params ) = @_;
-
-    # Allow 'cache_root' for backward compatibility with Cache::Filecache
-    if ( my $root = delete $self->{cache_root} ) {
-        $self->set_root_dir($root);
-    }
-}
-
 sub _build_path_to_namespace {
     my $self = shift;
 
@@ -303,9 +294,6 @@ to a directory called 'chi-driver-file' under the OS default temp directory
 (e.g. '/tmp' on UNIX). This directory will be created as needed on the first
 cache set.
 
-For backward compatibility with Cache::FileCache, this can also be specified as
-C<cache_root>.
-
 =item dir_create_mode
 
 Permissions mode to use when creating directories. Defaults to 0775.
