@@ -1,12 +1,11 @@
 package CHI::NullLogger;
-use Mouse;
+use Moose;
 use strict;
 use warnings;
 
 foreach my $level (qw(fatal error warn info debug)) {
-    no strict 'refs';
-    *{ __PACKAGE__ . "::$level" }    = sub { };
-    *{ __PACKAGE__ . "::is_$level" } = sub { undef };
+    __PACKAGE__->meta->add_method( $level      => sub { } );
+    __PACKAGE__->meta->add_method( "is_$level" => sub { undef } );
 }
 
 __PACKAGE__->meta->make_immutable();
